@@ -5,7 +5,7 @@ Created By Murray(m18527) on 2019/9/4 16:48
 from copy import deepcopy
 from .backbone import Backbone, BackboneV1, BackboneV2
 from ..models import Teacher, Student, Class, Classroom, Subject, CourseTableManager, RestTable, News, Notice, Album, \
-    Video, Image, School, MeetingRoom
+    Video, Image, School, MeetingRoom, EduOrgUser
 from ..models import CourseTableManagerV1
 from ..models import RestTableV2, CourseTableManagerV2, SemesterV2
 from ..utils.constants import ERROR_PARAMS, SUCCESS, MSG
@@ -539,6 +539,19 @@ class DataClient(object):
         backbone.delete_subject(uid)
         return
 
+    @staticmethod
+    def upload_user_avatar(school_id, file_path, user_id):
+        backbone = Backbone(school_id)
+        backbone.upload_user_avatar(file_path, user_id)
+
+    @staticmethod
+    def upload_user_face(school_id, file_path, student_id=None, teacher_id=None):
+        if not (student_id and teacher_id):
+            return None
+        data = {"student_id": student_id} if student_id else {"teacher_id": teacher_id}
+        backbone = Backbone(school_id)
+        backbone.upload_user_face(file_path, data)
+
 
 class DataClientV1(DataClient):
     @staticmethod
@@ -720,3 +733,62 @@ class DataClientV3(DataClient):
             return code, data
         else:
             return ERROR_PARAMS, "未查询到班级信息"
+
+    @staticmethod
+    def create_edu_org_user(edu_org_users):
+        """
+        create edu_org_user of edtech user server.
+        :param edu_org_users:  edu_org_user list or instance
+        :return: code, msg
+        """
+        is_multi, edu_org_user_map = True, {}
+        if not isinstance(edu_org_users, EduOrgUser) and not isinstance(edu_org_users, list):
+            logger.error("Error: No data or wrong student instance.")
+            return ERROR_PARAMS, "数据为空或格式不正确。"
+        if isinstance(edu_org_users, EduOrgUser):
+            edu_org_users = [edu_org_users]
+            is_multi = False
+        if edu_org_users and is_multi:
+            backbone = Backbone(school_id=None)
+            backbone.wrap_edu_org_user_map()
+            edu_org_user_map = backbone.edu_org_user_map
+
+        code_list, msg_list = [], []
+        for index, s in enumerate(edu_org_users):
+            if s.uid:
+                code, rlt = update_edu_org_user_req(s.uid, s.sso_data)
+            elif s.number in edu_org_user_map:
+                code, rlt = update_edu_org_user_req(edu_org_user_map[s.number], s.sso_data)
+            else:
+                code, rlt = create_edu_org_user_req(s.sso_data)
+            if code:
+                logger.error("Error, create edu org user fail, Detail: {}, Data: {}".format(rlt, s.sso_data))
+            code_list.append(code)
+            msg_list.append(rlt)
+            print(">>> Already create {}/{} edu org user".format(index + 1, len(edu_org_users)))
+
+        if is_multi:
+            return code_list, msg_list
+        return code_list[0], msg_list[0]
+
+    @staticmethod
+    def get_edu_org_user_info(params):
+        """
+        :param params: {"number":"xx", "name":"xx", "outer_id": ""}
+        :return:
+        """
+        code, data = get_edu_org_user_req(params)
+        if code:
+            logger.error("Error, query org_user info, Detail: {}".format(data))
+        return data
+
+    def delete_edu_org_user(self, params):
+        data = self.get_edu_org_user_info(params)
+        if len(data) > 1:
+            return ERROR_PARAMS, "查询行政管理人员信息不唯一"
+        elif len(data) == 1:
+            edu_user_id = data[0]['uuid']
+            code, data = delete_edu_org_user_req(edu_user_id)
+            return code, data
+        else:
+            return ERROR_PARAMS, "未查询到行政管理人员信息"
