@@ -22,6 +22,7 @@ class Backbone(object):
         self.subject_map = {}  # num -> uid
         self.classroom_map = {}  # num -> uid
         self.teacher_map = {}  # number -> uid
+        self.edu_org_user = {} # number -> uid
         self.student_map = {}  # number -> uid
         self.class_map = {}  # name -> uid
         self.album_map = {}  # name-category -> uid
@@ -655,6 +656,12 @@ class Backbone(object):
                     room_list.extend(room)
         return room_list
 
+    def upload_user_avatar(self, file_path, user_id):
+        self.edtech_requester.upload_user_avatar(file_path, user_id)
+
+    def upload_user_face(self, file_path, data):
+        self.nirvana_requester.upload_face_file(file_path, data)
+
     def upload_meeting_rooms(self, meeting_rooms):
         self.wrap_student_map()
         self.wrap_teacher_map()
@@ -662,6 +669,13 @@ class Backbone(object):
         self.clear_meeting_rooms()
         self.create_meeting_rooms(meeting_rooms)
 
+    def wrap_edu_org_user_map(self):
+        """
+        拉取行政管理人员列表，映射出uid
+        :return:
+        """
+        self.edu_org_user_map = self.edtech_requester.wrap_map("get_edu_org_user_list", ["number"], "uuid")
+
 
 class BackboneV1(Backbone):
     def __init__(self, school_id):
