@@ -33,3 +33,14 @@ class EDTechRequester(Requester):
         route = "/api/v1/schools/{}/students/".format(self.school_id)
         res = self._get_method(route, params=params)
         return res
+
+    def upload_user_avatar(self, file_path, user_id):
+        route = "/api/v1/users/{}/avatar/".format(user_id)
+        with open(file_path, 'rb') as f:
+            res = self._post_file_method(route, {'file': f})
+        return res
+
+    def get_edu_org_user_list(self, params={}):
+        route = "/api/v1/eduorguser/"
+        res = self._get_method(route, params=params)
+        return res
