@@ -38,5 +38,5 @@ class SchoolSync(BaseSync):
                             principal_name=name, principal_email=email_number, principal_phone=phone_number)
             logger.info(">>> Already add {}/{} school".format(index + 1, len(res_data)))
             print(">>> Already add {}/{} school".format(index + 1, len(res_data)))
-            self.client.create_school(school)
+            # self.client.create_school(school)
             self.school_map[name] = number
