@@ -13,9 +13,12 @@ class NewsSync(BaseSync):
 
     def crawl(self):
         for page in self.page_list:
+            print(">>> start crawl {}".format(page))
             ns = NewsSpider(page[0], page[1])
             ns.start()
             for target in ns.targets.values():
+                if not target.get("content", None):
+                    continue
                 news = News(title=target["topic"], content=target["content"])
                 self.news.append(news)
 
